MethodChannelFlutterHomescreenWidget class

The default FlutterHomescreenWidgetPlatform implementation using MethodChannel and EventChannel.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
onAction Stream<String>
A stream that emits action IDs when the user taps a widget area.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reloadWidget({required String widgetName}) Future<void>
Triggers a timeline reload for widgetName without updating the image.
override
toString() String
A string representation of this object.
inherited
updateWidget({required String widgetName, required Uint8List imageBytes, required List<Map<String, dynamic>> actions}) Future<void>
Saves imageBytes and actions to shared storage, then triggers a native widget timeline reload for widgetName.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited