FlutterHomescreenWidgetPlatform class abstract
The platform interface contract for FlutterHomescreenWidget.
Platform implementations must extend this class and set instance to themselves before any plugin methods are called.
- Inheritance
-
- Object
- PlatformInterface
- FlutterHomescreenWidgetPlatform
- Implementers
Constructors
- FlutterHomescreenWidgetPlatform()
- Constructs a FlutterHomescreenWidgetPlatform.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reloadWidget(
{required String widgetName}) → Future< void> -
Triggers a timeline reload for
widgetNamewithout updating the image. -
toString(
) → String -
A string representation of this object.
inherited
-
updateWidget(
{required String widgetName, required Uint8List imageBytes, required List< Map< actions}) → Future<String, dynamic> >void> -
Saves
imageBytesandactionsto shared storage, then triggers a native widget timeline reload forwidgetName.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterHomescreenWidgetPlatform
-
The current default FlutterHomescreenWidgetPlatform instance.
getter/setter pair