MethodChannelFlutterHomescreenWidget class
The default FlutterHomescreenWidgetPlatform implementation using MethodChannel and EventChannel.
- Inheritance
-
- Object
- PlatformInterface
- FlutterHomescreenWidgetPlatform
- MethodChannelFlutterHomescreenWidget
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reloadWidget(
{required String widgetName}) → Future< void> -
Triggers a timeline reload for
widgetNamewithout updating the image.override -
toString(
) → String -
A string representation of this object.
inherited
-
updateWidget(
{required String widgetName, required Uint8List imageBytes, required List< Map< actions}) → Future<String, dynamic> >void> -
Saves
imageBytesandactionsto shared storage, then triggers a native widget timeline reload forwidgetName.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited